        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 13 <br>2,3,6,10,11,14,20,21,23,32,43,45,49';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 12 <strong>control</strong><br>0,7,13,16,17,22,28,29,35,39,40,46';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 12 <br>4,8,25,27,30,31,33,36,37,38,41,50';}
       if(rr==3 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 8 <br>1,9,18,19,24,26,47,48';}
       if(rr==3 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>44</strong> miembros: 4 <br>5,34,42,44';}
       if(rr==3 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>12</strong> miembros: 2 <br>12,15';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 13 <br>2,3,6,10,11,14,20,21,23,32,43,45,49';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 12 <strong>control</strong><br>0,7,13,16,17,22,28,29,35,39,40,46';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 12 <br>4,8,25,27,30,31,33,36,37,38,41,50';}
       if(rr==17 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 8 <br>1,9,18,19,24,26,47,48';}
       if(rr==17 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>44</strong> miembros: 4 <br>5,34,42,44';}
       if(rr==17 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>12</strong> miembros: 2 <br>12,15';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 13 <br>2,3,6,10,11,14,20,21,23,32,43,45,49';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 12 <strong>control</strong><br>0,7,13,16,17,22,28,29,35,39,40,46';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 12 <br>4,8,25,27,30,31,33,36,37,38,41,50';}
       if(rr==19 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 8 <br>1,9,18,19,24,26,47,48';}
       if(rr==19 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>44</strong> miembros: 4 <br>5,34,42,44';}
       if(rr==19 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>12</strong> miembros: 2 <br>12,15';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 13 <br>2,3,6,10,11,14,20,21,23,32,43,45,49';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 12 <strong>control</strong><br>0,7,13,16,17,22,28,29,35,39,40,46';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 12 <br>4,8,25,27,30,31,33,36,37,38,41,50';}
       if(rr==20 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 8 <br>1,9,18,19,24,26,47,48';}
       if(rr==20 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>44</strong> miembros: 4 <br>5,34,42,44';}
       if(rr==20 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>12</strong> miembros: 2 <br>12,15';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 13 <br>2,3,6,10,11,14,20,21,23,32,43,45,49';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 12 <strong>control</strong><br>0,7,13,16,17,22,28,29,35,39,40,46';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 12 <br>4,8,25,27,30,31,33,36,37,38,41,50';}
       if(rr==21 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 8 <br>1,9,18,19,24,26,47,48';}
       if(rr==21 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>44</strong> miembros: 4 <br>5,34,42,44';}
       if(rr==21 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>12</strong> miembros: 2 <br>12,15';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 13 <br>2,3,6,10,11,14,20,21,23,32,43,45,49';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 12 <strong>control</strong><br>0,7,13,16,17,22,28,29,35,39,40,46';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 12 <br>4,8,25,27,30,31,33,36,37,38,41,50';}
       if(rr==22 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 8 <br>1,9,18,19,24,26,47,48';}
       if(rr==22 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>44</strong> miembros: 4 <br>5,34,42,44';}
       if(rr==22 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260510 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>12</strong> miembros: 2 <br>12,15';}
}
